# tweeta

A collection of utilities for parsing tweet objects (collected through Twitter API).

## Installation

### Install using `pip`
```bash
pip install tweeta
```

### Install from source

```bash
python setup.py install
```

## Usage

Sphinx docs [here](https://bianjiang.github.io/tweeta/)
